@@ -4,9 +4,10 @@ from PyQt4.QtGui import *
 from field import Field
 from human import Human
 from computer_random import ComputerRandom
+from computer_most import ComputerMost
 import logging
 
-class Table(QGraphicsScene):
+class Table(QGraphicsObject):
     players = []
     player = False
     compas = [
@@ -18,84 +19,32 @@ class Table(QGraphicsScene):
     moves = dict()
     history = []
     fields = []
+    playerPass = 0
 
-    def __init__(self, parent = None, maemo = False):
-        QGraphicsScene.__init__(self, parent)
+    def __init__(self, parent = None, size = None, maemo = False):
+        QGraphicsObject.__init__(self, parent)
 
-        geometry = parent.geometry()
-        if geometry.height() > geometry.width(): self.size = geometry.width() - 10
-        else: self.size = geometry.height() - 10
-        self.setSceneRect(0, 0, self.size, self.size)
+        #if geometry.height() > geometry.width(): self.size = geometry.width()
+        #else: self.size = geometry.height()
+        #self.scene.setSceneRect(0, 0, self.size, self.size)
+        self.size = size
 
         size = ((self.size)/8) - 3
 
         for i in range(0, 8):
             row = []
             for j in range(0, 8):
-                field = Field(size = size, x = i, y = j, maemo = maemo)
+                field = Field(self, size = size, x = i, y = j, maemo = maemo)
+                #field.setParentItem(self)
                 row.append(field)
-                self.addItem(field)
             self.fields.append(row)
 
         player = Human(self)
         self.players.append(player)
 
-        computer = ComputerRandom(self)
+        computer = ComputerMost(self)
         self.players.append(computer)
 
-        """
-        self.fields[1][1].starting(True)
-        self.fields[1][2].starting(False)
-        self.fields[2][1].starting(False)
-        self.fields[2][2].starting(True)
-
-        self.fields[1][0].starting(True)
-
-        self.fields[2][1].starting(True)
-
-        self.fields[2][2].starting(False)
-        self.fields[3][2].starting(True)
-        self.fields[4][2].starting(True)
-
-        self.fields[0][3].starting(True)
-        self.fields[2][3].starting(True)
-        self.fields[3][3].starting(True)
-        self.fields[4][3].starting(True)
-        self.fields[5][3].starting(True)
-
-        self.fields[0][4].starting(True)
-        self.fields[1][4].starting(True)
-        self.fields[2][4].starting(True)
-        self.fields[3][4].starting(True)
-        self.fields[4][4].starting(True)
-        self.fields[5][4].starting(True)
-        self.fields[6][4].starting(True)
-
-        self.fields[0][5].starting(False)
-        self.fields[1][5].starting(True)
-        self.fields[2][5].starting(True)
-        self.fields[3][5].starting(False)
-        self.fields[4][5].starting(True)
-        self.fields[7][5].starting(True)
-
-        self.fields[0][6].starting(False)
-        self.fields[1][6].starting(False)
-        self.fields[2][6].starting(True)
-        self.fields[3][6].starting(True)
-        self.fields[4][6].starting(True)
-        self.fields[7][6].starting(True)
-
-        self.fields[0][7].starting(False)
-        self.fields[1][7].starting(False)
-        self.fields[2][7].starting(False)
-        """
-        #for i in range(0, 8):
-        #    for j in range(0, 8):
-        #        if (i == 2 and j == 2) or (i == 4 and j == 4): continue
-        #        self.fields[i][j].starting(True)
-
-        #self.fields[2][2].starting(False)
-
         self.fields[3][3].starting(True)
         self.fields[4][3].starting(False)
         self.fields[3][4].starting(False)
@@ -104,6 +53,12 @@ class Table(QGraphicsScene):
         self.newGame()
         #self.connect(self.fields[0][0] , SIGNAL('clicked'), self.makeMove)
 
+    def paint(self, painter, option, widget):
+        pass
+
+    def boundingRect(self):
+        return QRectF(0, 0, self.size, self.size)
+
     def newGame(self):
         #print 'new game'
         for i in range(0, 8):
@@ -113,6 +68,7 @@ class Table(QGraphicsScene):
         self.players[int(self.player)].activate()
         self.emit(SIGNAL('setScores'), [2, 2])
         self.hitstory = []
+        self.playerPass = 0
         self._calculatePossibleMoves()
         #print self.moves
 
@@ -134,8 +90,8 @@ class Table(QGraphicsScene):
                         #fields.extend(turnFields)
                         turnFields.reverse()
                         self.fields[turnFields[0][0]][turnFields[0][1]].setPossible(True)
-                        try: self.moves['%s-%s' % (turnFields[0][0], turnFields[0][1])][1].extend(turnFields)
-                        except: self.moves.update({'%s-%s' % (turnFields[0][0], turnFields[0][1]) : [[turnFields[0][0], turnFields[0][1]], turnFields]})
+                        try: self.moves['%s-%s' % (turnFields[0][0], turnFields[0][1])][1].extend(turnFields[1:])
+                        except: self.moves.update({'%s-%s' % (turnFields[0][0], turnFields[0][1]) : [[turnFields[0][0], turnFields[0][1]], turnFields[1:]]})
 
                 #print self.moves
 
@@ -195,8 +151,15 @@ class Table(QGraphicsScene):
         self.player = True if not self.player else False
         self._calculatePossibleMoves()
         #print self.moves
+        if not self.moves:
+            if self.playerPass >= 2:
+                self.emit(SIGNAL('gameOver'), scores)
+                return False
+            self.playerPass += 1
+            if not self.nextPlayer():
+                return False
+        self.playerPass = 0
         self.players[int(self.player)].activate()
-        if not self.moves: self.nextPlayer()
 
     def getPosibleMoves(self):
         return self.moves
